@@ -1,13 +1,15 @@
-import argparse
-from argparse import Namespace
+from argparse import ArgumentParser, Namespace
 from pathlib import Path
-from typing import Iterable
+from typing import TYPE_CHECKING, Iterable
 
 import shtab
 
 from ldb.config import set_default_instance
 from ldb.core import init
 
+if TYPE_CHECKING:
+    from argparse import _SubParsersAction
+
 
 def init_command(options: Namespace) -> None:
     init(options.path, force=options.force, read_any_cloud_location=False)
@@ -15,8 +17,8 @@ def init_command(options: Namespace) -> None:
 
 
 def add_parser(
-    subparsers: argparse._SubParsersAction,
-    parents: Iterable[argparse.ArgumentParser],
+    subparsers: "_SubParsersAction[ArgumentParser]",
+    parents: Iterable[ArgumentParser],
 ) -> None:
     parser = subparsers.add_parser(
         "init",
@@ -32,6 +34,7 @@ def add_parser(
     )
     parser.add_argument(  # type: ignore[attr-defined]
         "path",
+        metavar="<path>",
         type=Path,
         help="Directory in which to initialize new instance",
     ).complete = shtab.DIRECTORY
