@@ -1,11 +1,13 @@
-import argparse
-from argparse import Namespace
-from typing import Iterable
+from argparse import ArgumentParser, Namespace
+from typing import TYPE_CHECKING, Iterable
 
 from ldb.cli_utils import add_data_obj_params
 from ldb.core import get_ldb_instance
 from ldb.ls import ls, print_dataset_listings
 
+if TYPE_CHECKING:
+    from argparse import _SubParsersAction
+
 
 def ls_command(options: Namespace) -> None:
     ldb_dir = get_ldb_instance()
@@ -13,6 +15,7 @@ def ls_command(options: Namespace) -> None:
         ldb_dir,
         options.paths,
         options.query_args,
+        warn=False,
     )
     if options.summary:
         print(len(ds_listings))
@@ -25,8 +28,8 @@ def ls_command(options: Namespace) -> None:
 
 
 def add_parser(
-    subparsers: argparse._SubParsersAction,
-    parents: Iterable[argparse.ArgumentParser],
+    subparsers: "_SubParsersAction[ArgumentParser]",
+    parents: Iterable[ArgumentParser],
 ) -> None:
     parser = subparsers.add_parser(
         "list",
