@@ -81,6 +81,7 @@ class DatasetVersion:
     collection: str
     tags: List[str]
     commit_info: CommitInfo
+    transform_mapping_id: str = ""
 
     @classmethod
     def parse(cls, attr_dict: Dict[str, Any]) -> "DatasetVersion":
@@ -118,6 +119,10 @@ class Dataset:
         return dict(created=created, **attr_dict)
 
 
+class ObjectIDMapping(Dict[str, str]):
+    pass
+
+
 def iter_collection_dir(collection_dir: Union[str, Path]) -> Iterator[str]:
     return iglob(os.path.join(collection_dir, "*", "*"))
 
@@ -370,6 +375,16 @@ class Sample(CollectionOperation):
                 yield c
 
 
+class Shuffle(CollectionOperation):
+    def apply(
+        self,
+        collection: Iterable[Tuple[str, str]],
+    ) -> Iterator[Tuple[str, str]]:
+        collection_list = list(collection)
+        random.shuffle(collection_list)
+        yield from collection_list
+
+
 class Sort(CollectionOperation):
     def __init__(self, ldb_dir: Path, proc_args: List[str]) -> None:
         self.ldb_dir = ldb_dir
@@ -509,6 +524,8 @@ class PipelineBuilder:
             elif op_type == OpType.SAMPLE:
                 assert isinstance(arg, float)
                 op = Sample(arg).apply
+            elif op_type == OpType.SHUFFLE:
+                op = Shuffle().apply
             elif op_type == OpType.PIPE:
                 assert isinstance(arg, list)
                 op = Sort(self.ldb_dir, arg).apply
