@@ -249,10 +249,10 @@ class PairIndexer(Indexer):
                 strict_format=self.strict_format,
             )
 
-            for fs, fs_paths in self.old_to_new_annot_files.items():
+            for _, fs_paths in self.old_to_new_annot_files.items():
                 for _, new in fs_paths.items():
                     annotation_paths.setdefault(new.fs, []).append(new.path)
-            for fs, fs_paths in self.old_to_new_files.items():
+            for _, fs_paths in self.old_to_new_files.items():
                 for _, new in fs_paths.items():
                     files.setdefault(new.fs, []).append(new.path)
         indexing_jobs: IndexingJobMapping = {}
