@@ -1,7 +1,7 @@
 from dataclasses import dataclass
 from itertools import chain
 from pathlib import Path
-from typing import Dict, List, Tuple, Union
+from typing import Collection, Dict, List, Tuple, Union
 
 from fsspec.spec import AbstractFileSystem
 from funcy.objects import cached_property
@@ -20,6 +20,7 @@ from ldb.index.utils import (
     IndexingJobMapping,
     construct_annotation_meta,
     expand_dir_paths,
+    is_hidden_fsspec_path,
 )
 from ldb.typing import JSONDecoded, JSONObject
 from ldb.utils import current_time, load_data_file
@@ -35,7 +36,11 @@ class InferredPreprocessor(Preprocessor):
         for fs, dir_paths in dir_path_lists.items():
             fs_seq: Dict[str, List[str]] = file_seqs.setdefault(fs, {})
             for p in dir_paths:
-                file_paths: List[str] = fs.find(p.rstrip("/"))
+                file_paths: List[str] = [
+                    p
+                    for p in fs.find(p.rstrip("/"))
+                    if not is_hidden_fsspec_path(p)
+                ]
                 if file_paths:
                     fs_seq[p] = file_paths
         return file_seqs
@@ -77,6 +82,7 @@ class InferredIndexer(PairIndexer):
         preprocessor: InferredPreprocessor,
         read_any_cloud_location: bool,
         strict_format: bool,
+        tags: Collection[str] = (),
     ) -> None:
         self.preprocessor: InferredPreprocessor
         super().__init__(
@@ -84,6 +90,7 @@ class InferredIndexer(PairIndexer):
             preprocessor,
             read_any_cloud_location,
             strict_format,
+            tags,
         )
 
     def infer_annotations(
@@ -124,6 +131,7 @@ class InferredIndexer(PairIndexer):
         self.index_inferred_files(
             indexing_jobs,
             annotations_by_data_object_path,
+            self.tags,
         )
 
     def index_inferred_files(
@@ -133,6 +141,7 @@ class InferredIndexer(PairIndexer):
             Tuple[AbstractFileSystem, str],
             JSONObject,
         ],
+        tags: Collection[str],
     ) -> None:
         for fs, jobs in indexing_jobs.items():
             for config, path_seq in jobs:
@@ -140,6 +149,7 @@ class InferredIndexer(PairIndexer):
                     item = InferredIndexingItem(
                         self.ldb_dir,
                         current_time(),
+                        tags,
                         FileSystemPath(fs, data_object_path),
                         config.save_data_object_path_info,
                         self.hashes,
