@@ -114,8 +114,8 @@ def expand_single_indexing_path(
     """
     # TODO: make sure path is in a storage location if necessary
     protocol = get_protocol(path)
-    fs = fsspec.filesystem(protocol)
-    path = fs._strip_protocol(path)  # pylint: disable=protected-access
+    fs_cls = fsspec.get_filesystem_class(protocol)
+    path = fs_cls._strip_protocol(path)  # pylint: disable=protected-access
     fs = get_filesystem(path, protocol, storage_locations)
     if protocol == "file":
         path = os.path.abspath(path)
@@ -153,7 +153,7 @@ def expand_single_indexing_path(
 
 
 def is_hidden_fsspec_path(path: str) -> bool:
-    return re.search(r"^\.|/\.", path) is not None
+    return re.search(r"(?:/|^)\.(?!/|$)", path) is not None
 
 
 def group_indexing_paths_by_type(
@@ -188,11 +188,12 @@ def expand_dir_paths(
 
     path_sets: Dict[AbstractFileSystem, Set[str]] = {}
     for path in paths:
-        fs = fsspec.filesystem(get_protocol(path))
-        fs_paths = path_sets.setdefault(fs, set())
-        for p in fs.expand_path(paths):
-            if fs.isdir(p):
-                fs_paths.add(p)
+        if not is_hidden_fsspec_path(path):
+            fs = fsspec.filesystem(get_protocol(path))
+            fs_paths = path_sets.setdefault(fs, set())
+            for p in fs.expand_path(paths):
+                if not is_hidden_fsspec_path(p) and fs.isdir(p):
+                    fs_paths.add(p)
     path_lists: Dict[AbstractFileSystem, List[str]] = {}
     for fs, fs_path_set in path_sets.items():
         paths = sorted(fs_path_set)
@@ -452,6 +453,7 @@ def construct_data_object_meta(
     path: str,
     prev_meta: Dict[str, Any],
     current_timestamp: str,
+    tags: Collection[str] = (),
 ) -> DataObjectMeta:
     # TODO: create dataclass for data object meta
     fs_info = fs.info(path)
@@ -468,15 +470,15 @@ def construct_data_object_meta(
 
     if prev_meta:
         first_indexed = prev_meta["first_indexed"]
-        tags = prev_meta["tags"]
+        new_tags = sorted(set(prev_meta["tags"]) | set(tags))
         alternate_paths = prev_meta["alternate_paths"]
         atime = max_datetime_info(atime, prev_meta["fs"]["atime"])
         mtime = max_datetime_info(mtime, prev_meta["fs"]["mtime"])
         ctime = max_datetime_info(ctime, prev_meta["fs"]["ctime"])
-        filetype = filetype or prev_meta["fs"]["type"]
+        filetype = filetype or prev_meta["type"]
     else:
         first_indexed = current_timestamp
-        tags = []
+        new_tags = sorted(set(tags))
         alternate_paths = []
 
     protocol: Union[str, List[str]] = fs.protocol
@@ -492,7 +494,7 @@ def construct_data_object_meta(
         "first_indexed": first_indexed,
         "last_indexed": current_timestamp,
         "last_indexed_by": last_indexed_by,
-        "tags": tags,
+        "tags": new_tags,  # type: ignore[dict-item]
         "alternate_paths": alternate_paths,
         "fs": {
             **path_info,
