@@ -5,8 +5,11 @@ import random
 import re
 import stat
 import string
+import sys
 from contextlib import contextmanager
 from datetime import datetime, timezone
+from enum import Enum
+from functools import partial
 from pathlib import Path
 from typing import (
     TYPE_CHECKING,
@@ -44,6 +47,15 @@ _KT_contra = TypeVar("_KT_contra", contravariant=True)
 _VT_co = TypeVar("_VT_co", covariant=True)
 _T = TypeVar("_T")
 
+if sys.version_info < (3, 9):
+    md5 = hashlib.md5
+else:
+    md5 = partial(hashlib.md5, usedforsecurity=False)
+
+
+class StrEnum(str, Enum):
+    pass
+
 
 @overload
 def get_first(
@@ -108,7 +120,7 @@ def get_file_hash(fs: AbstractFileSystem, path: str) -> str:
 
 
 def hash_file(fs: AbstractFileSystem, path: str) -> str:
-    hash_obj = hashlib.md5()
+    hash_obj = md5()
     with fs.open(path, "rb") as file:
         for chunk in iter_chunks(file):
             hash_obj.update(chunk)
@@ -116,7 +128,7 @@ def hash_file(fs: AbstractFileSystem, path: str) -> str:
 
 
 def hash_data(data: bytes) -> str:
-    return hashlib.md5(data).hexdigest()
+    return md5(data).hexdigest()
 
 
 def iter_chunks(
@@ -238,3 +250,25 @@ def temp_dataset_name(dt: Optional[datetime] = None) -> str:
         dt = current_time()
     timestamp = format_datetime(dt)
     return f".temp.{timestamp}"
+
+
+def make_target_dir(path: Union[str, Path], parents: bool = False) -> bool:
+    """
+    Make a target directory if it does not exist.
+
+    Return whether or not a new directory was created
+    """
+    try:
+        if parents:
+            os.makedirs(path)
+        else:
+            os.mkdir(path)
+    except FileExistsError:
+        if not os.path.isdir(path):
+            raise NotADirectoryError(  # pylint: disable=raise-missing-from
+                f"Not a directory: {os.fspath(path)!r}",
+            )
+        created = False
+    else:
+        created = True
+    return created
